@@ -19,13 +19,11 @@
 
  */
 
-#include <stddef.h>
-#include <stdio.h>
-#include <string.h>
-#include <limits.h>
+#include "defs.h"
+#include <stdlib.h> // atof
+#include <stdio.h> // sprintf
 
 #define MYNAME "an1"
-#include "defs.h"
 
 static gbfile* infile;
 static gbfile* outfile;
@@ -777,10 +775,10 @@ Write_One_AN1_Waypoint(const Waypoint* wpt)
 #if NEW_STRINGS
     char* extra = (char*) xmalloc(25 + wpt->gc_data->placer.length() + wpt->shortname.length());
 #else
-    char* extra = (char*) xmalloc(25 + strlen(wpt->gc_data->placer.toUtf8().data()) + strlen(wpt->shortname));
+    char* extra = (char*) xmalloc(25 + strlen(CSTR(wpt->gc_data->placer)) + strlen(wpt->shortname));
 #endif
     sprintf(extra, "\r\nBy %s\r\n%s (%1.1f/%1.1f)",
-            wpt->gc_data->placer.toUtf8().data(),
+            CSTR(wpt->gc_data->placer),
             CSTRc(wpt->shortname), wpt->gc_data->diff/10.0,
             wpt->gc_data->terr/10.0);
     rec->name = xstrappend(rec->name, extra);
@@ -791,7 +789,7 @@ Write_One_AN1_Waypoint(const Waypoint* wpt)
     UrlLink l = wpt->GetUrlLink();
     int len = 7 + l.url_.length();
     char* extra = (char*)xmalloc(len);
-    sprintf(extra, "{URL=%s}", l.url_.toUtf8().data());
+    sprintf(extra, "{URL=%s}", CSTR(l.url_));
     rec->name = xstrappend(rec->name, extra);
     xfree(extra);
     if(rec->url) {
@@ -814,16 +812,13 @@ Write_One_AN1_Waypoint(const Waypoint* wpt)
 
   if (rec->type == 0x12) {    /* image */
     if (wpt->icon_descr.contains(":\\")) {
-      rec->image_name = xstrdup(wpt->icon_descr.toUtf8().data());
+      rec->image_name = xstrdup(wpt->icon_descr);
       rec->height = -244;
       rec->width = -1;
     }
   }
   if (!rec->image_name && !wpt->icon_descr.isNull()) {
-// FIXME: WTH?
-    char* t = xstrdup(wpt->icon_descr.toUtf8().data());
-    FindIconByName(t, &rec->guid);
-    xfree(t);
+    FindIconByName(CSTR(wpt->icon_descr), &rec->guid);
   }
 
   Write_AN1_Waypoint(outfile, rec);
