@@ -28,14 +28,12 @@
  * 1998, version 2.1: http://www.exif.org/Exif2-1.PDF
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include "defs.h"
 #include "garmin_tables.h"
 #include "jeeps/gpsmath.h"
+#include <stdio.h>
+#include <stdlib.h>
+#include <math.h>
 
 #define MYNAME "exif"
 
@@ -861,19 +859,16 @@ exif_waypt_from_exif_app(exif_app_t* app)
 
   tag = exif_find_tag(app, EXIF_IFD, EXIF_IFD_TAG_USER_CMT); /* UserComment */
   if (tag && (tag->size > 8)) {
-    char* str = NULL;
+    QString str;
     if (memcmp(tag->data, "ASCII\0\0\0", 8) == 0) {
-      str = xstrndup((char*)tag->data + 8, tag->size - 8);
+      wpt->notes = QString::fromLatin1((char*) tag->data + 8, tag->size - 8);
     } else if (memcmp(tag->data, "UNICODE\0", 8) == 0) {
-      int i, len = (tag->size - 8) / 2;
-      int16_t* s = (int16_t*)((char*)tag->data + 8);
-      for (i = 0; i < len; i++) {
-        s[i] = be_read16(&s[i]);  /* always BE ? */
-      }
-      str = cet_str_uni_to_any(s, len, global_opts.charset);
-    }
-    if (str != NULL) {
-      wpt->notes = str;
+      // I'm not at all sure that casting alignment away like this is a good
+      // idea in light of arches that don't allow unaligned loads, but in the
+      // absence of test data that captures it and the grubbiness of the code
+      // that was here before, I'm going to do this and then come back to it
+      // if it's a problem.
+      wpt->notes = QString::fromUtf16((const uint16_t*)((char*) tag->data + 8), tag->size - 8);
     }
   }
 
@@ -1375,7 +1370,6 @@ static void
 exif_wr_init(const char* fname)
 {
   uint16_t soi;
-  char* tmpname;
 
   exif_success = 0;
   exif_fout_name = xstrdup(fname);
@@ -1397,9 +1391,9 @@ exif_wr_init(const char* fname)
     fatal(MYNAME ": No valid timestamp found in picture!\n");
   }
 abort();
-  xasprintf(&tmpname, "%s.jpg", fname);
-  fout = gbfopen_be(tmpname, "wb", MYNAME);
-  xfree(tmpname);
+  QString filename(fname);
+  filename += ".jpg";
+  fout = gbfopen_be(filename, "wb", MYNAME);
 }
 
 static void
@@ -1454,11 +1448,11 @@ exif_write(void)
     if (exif_wpt_ref == NULL) {
       warning(MYNAME ": No point with a valid timestamp found.\n");
     } else if (abs(exif_time_ref - exif_wpt_ref->creation_time.toTime_t()) > frame) {
-      warning(MYNAME ": No matching point found for image date %s!\n", CSTR(str));
+      warning(MYNAME ": No matching point found for image date %s!\n", qPrintable(str));
       if (exif_wpt_ref != NULL) {
         QString str = exif_time_str(exif_wpt_ref->creation_time.toTime_t());
         warning(MYNAME ": Best is from %s, %d second(s) away.\n",
-                CSTR(str), abs(exif_time_ref - exif_wpt_ref->creation_time.toTime_t()));
+                qPrintable(str), abs(exif_time_ref - exif_wpt_ref->creation_time.toTime_t()));
       }
       exif_wpt_ref = NULL;
     }
