@@ -29,13 +29,13 @@
 
 class FormatLoad {
  public:
-  FormatLoad() {};
+  FormatLoad() : currentLine_(0) {};
   ~FormatLoad() {};
   
   bool getFormats(QList<Format> &formatList);
  private:
-  QStringList lines;
-  int currentLine;
+  QStringList lines_;
+  int currentLine_;
   bool skipToValidLine();
   bool processFormat(Format &format);
 };
