@@ -1015,10 +1015,6 @@ p, li { white-space: pre-wrap; }
         <source>Input data format</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Character encoding of input</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Browse for one or more input files. </source>
         <translation type="unfinished"></translation>
@@ -1107,10 +1103,6 @@ p, li { white-space: pre-wrap; }
         <source>Output data format.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Character encoding of output</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Browse for an output file name. </source>
         <translation type="unfinished"></translation>
@@ -1151,10 +1143,6 @@ p, li { white-space: pre-wrap; }
         <source>Preferences...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>default</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Select one or more input files</source>
         <translation type="unfinished"></translation>
