@@ -437,8 +437,8 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="mainwinui.ui" line="44"/>
-        <location filename="mainwinui.ui" line="438"/>
-        <location filename="mainwinui.ui" line="642"/>
+        <location filename="mainwinui.ui" line="431"/>
+        <location filename="mainwinui.ui" line="628"/>
         <source>File</source>
         <translation type="unfinished"></translation>
     </message>
@@ -449,13 +449,13 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="mainwinui.ui" line="60"/>
-        <location filename="mainwinui.ui" line="454"/>
+        <location filename="mainwinui.ui" line="447"/>
         <source>Device</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwinui.ui" line="89"/>
-        <location filename="mainwinui.ui" line="483"/>
+        <location filename="mainwinui.ui" line="476"/>
         <source>Format</source>
         <translation type="unfinished"></translation>
     </message>
@@ -465,333 +465,317 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="103"/>
-        <source>Character encoding of input</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="mainwinui.ui" line="127"/>
+        <location filename="mainwinui.ui" line="120"/>
         <source>Browse for one or more input files. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="130"/>
+        <location filename="mainwinui.ui" line="123"/>
         <source>File Name(s)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="162"/>
-        <location filename="mainwinui.ui" line="553"/>
+        <location filename="mainwinui.ui" line="155"/>
+        <location filename="mainwinui.ui" line="539"/>
         <source>Device Name:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="169"/>
+        <location filename="mainwinui.ui" line="162"/>
         <source>Name of port to which input device is connected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="200"/>
+        <location filename="mainwinui.ui" line="193"/>
         <source>Options for the selected input format. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="203"/>
-        <location filename="mainwinui.ui" line="594"/>
+        <location filename="mainwinui.ui" line="196"/>
+        <location filename="mainwinui.ui" line="580"/>
         <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="228"/>
+        <location filename="mainwinui.ui" line="221"/>
         <source>Translation Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="237"/>
-        <location filename="mainwinui.ui" line="280"/>
-        <location filename="mainwinui.ui" line="320"/>
+        <location filename="mainwinui.ui" line="230"/>
+        <location filename="mainwinui.ui" line="273"/>
+        <location filename="mainwinui.ui" line="313"/>
         <source>-</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="247"/>
+        <location filename="mainwinui.ui" line="240"/>
         <source>If selected, translate waypoints.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="250"/>
+        <location filename="mainwinui.ui" line="243"/>
         <source>Waypoints</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="287"/>
+        <location filename="mainwinui.ui" line="280"/>
         <source>If selected, translate routes.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="290"/>
+        <location filename="mainwinui.ui" line="283"/>
         <source>Routes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="327"/>
+        <location filename="mainwinui.ui" line="320"/>
         <source>If selected, translate tracks.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="330"/>
+        <location filename="mainwinui.ui" line="323"/>
         <source>Tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="366"/>
+        <location filename="mainwinui.ui" line="359"/>
         <source>Data Filters between input and output</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="369"/>
+        <location filename="mainwinui.ui" line="362"/>
         <source>Filters</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="402"/>
+        <location filename="mainwinui.ui" line="395"/>
         <source>More translation options. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="405"/>
+        <location filename="mainwinui.ui" line="398"/>
         <source>More Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="415"/>
+        <location filename="mainwinui.ui" line="408"/>
         <source>Output</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="435"/>
+        <location filename="mainwinui.ui" line="428"/>
         <source>If selected, output is to a file. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="451"/>
+        <location filename="mainwinui.ui" line="444"/>
         <source>If selected, output is to a device or GPS unit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="490"/>
+        <location filename="mainwinui.ui" line="483"/>
         <source>Output data format.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="497"/>
-        <source>Character encoding of output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="mainwinui.ui" line="518"/>
+        <location filename="mainwinui.ui" line="504"/>
         <source>Browse for an output file name. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="521"/>
+        <location filename="mainwinui.ui" line="507"/>
         <source>File Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="560"/>
+        <location filename="mainwinui.ui" line="546"/>
         <source>Name of port to which output device is connected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="591"/>
+        <location filename="mainwinui.ui" line="577"/>
         <source>Options for the selected output format. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="615"/>
+        <location filename="mainwinui.ui" line="601"/>
         <source>Output of GPSBabel translation process. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="649"/>
+        <location filename="mainwinui.ui" line="635"/>
         <source>Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="665"/>
+        <location filename="mainwinui.ui" line="651"/>
         <source>GPSBabel Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="670"/>
+        <location filename="mainwinui.ui" line="656"/>
         <source>About GPSBabel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="675"/>
+        <location filename="mainwinui.ui" line="661"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="680"/>
+        <location filename="mainwinui.ui" line="666"/>
         <source>Preferences...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="685"/>
+        <location filename="mainwinui.ui" line="671"/>
         <source>Check for Upgrade</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="690"/>
+        <location filename="mainwinui.ui" line="676"/>
         <source>Visit Website...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwinui.ui" line="695"/>
+        <location filename="mainwinui.ui" line="681"/>
         <source>Make a Donation...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="399"/>
-        <location filename="mainwindow.cc" line="400"/>
-        <source>default</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cc" line="573"/>
+        <location filename="mainwindow.cc" line="528"/>
         <source>Select one or more input files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="600"/>
+        <location filename="mainwindow.cc" line="555"/>
         <source>Output File Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="660"/>
+        <location filename="mainwindow.cc" line="615"/>
         <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH
 
 This program cannot continue.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="671"/>
+        <location filename="mainwindow.cc" line="626"/>
         <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH
 
 This program cannot continue.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="693"/>
+        <location filename="mainwindow.cc" line="648"/>
         <source>Input and output formats do not support %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="696"/>
+        <location filename="mainwindow.cc" line="651"/>
         <source>Input does not support %1; output format supports %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="699"/>
+        <location filename="mainwindow.cc" line="654"/>
         <source>Input format supports %1; output format does not support %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="702"/>
+        <location filename="mainwindow.cc" line="657"/>
         <source>Both input and output formats support %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="723"/>
+        <location filename="mainwindow.cc" line="678"/>
         <source>waypoints</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="724"/>
+        <location filename="mainwindow.cc" line="679"/>
         <source>tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="725"/>
+        <location filename="mainwindow.cc" line="680"/>
         <source>routes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="815"/>
+        <location filename="mainwindow.cc" line="770"/>
         <source>There are no input options for format &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="822"/>
-        <location filename="mainwindow.cc" line="842"/>
+        <location filename="mainwindow.cc" line="777"/>
+        <location filename="mainwindow.cc" line="797"/>
         <source>Options for %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="835"/>
+        <location filename="mainwindow.cc" line="790"/>
         <source>There are no output options for format &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="856"/>
+        <location filename="mainwindow.cc" line="811"/>
         <source>No valid waypoints/routes/tracks translation specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="875"/>
+        <location filename="mainwindow.cc" line="830"/>
         <source>No input file specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="882"/>
+        <location filename="mainwindow.cc" line="837"/>
         <source>No valid output specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="887"/>
+        <location filename="mainwindow.cc" line="842"/>
         <source>No output file specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="903"/>
+        <location filename="mainwindow.cc" line="858"/>
         <source>Process &quot;%1&quot; did not start</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="917"/>
+        <location filename="mainwindow.cc" line="872"/>
         <source>Process exited unsucessfully with code %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1060"/>
+        <location filename="mainwindow.cc" line="1007"/>
         <source>Translation successful</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1071"/>
+        <location filename="mainwindow.cc" line="1018"/>
         <source>Error running gpsbabel: %1
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1184"/>
+        <location filename="mainwindow.cc" line="1131"/>
         <source>Are you sure you want to reset all format options to default values?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1208"/>
+        <location filename="mainwindow.cc" line="1154"/>
         <source>About %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1251"/>
+        <location filename="mainwindow.cc" line="1197"/>
         <source>One or more data filters are active</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1253"/>
+        <location filename="mainwindow.cc" line="1199"/>
         <source>No data filters are active</source>
         <translation type="unfinished"></translation>
     </message>
