@@ -1,8 +1,3 @@
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
 #ifndef gpsread_h
 #define gpsread_h
 
@@ -14,7 +9,3 @@ extern "C"
   int32  GPS_Serial_Get_Ack(gpsdevh* fd, GPS_PPacket* tra, GPS_PPacket* rec);
 
 #endif
-
-#ifdef __cplusplus
-}
-#endif
