@@ -19,14 +19,16 @@
 
  */
 
-#include <string.h>
-#include <ctype.h>
-#include <stdlib.h>
-
 #include "defs.h"
 #include "cet.h"
 #include "cet_util.h"
 
+#include <ctype.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+
 #define MYNAME	"mkshort"
 
 static const char vowels[] = "aeiouAEIOU";
@@ -293,7 +295,7 @@ setshort_repeating_whitespace_ok(short_handle h, int l)
 
 /*
  * Set default name given to a waypoint if no valid is possible
- * becuase it was filtered by charsets or null or whatever.
+ * because it was filtered by charsets or null or whatever.
  */
 void
 setshort_defname(short_handle h, const char* s)
