@@ -20,10 +20,11 @@
 
 */
 
-#include <QtCore/QXmlStreamAttributes>
 
 #include "defs.h"
 #include "xmlgeneric.h"
+#include <QtCore/QHash>
+#include <QtCore/QXmlStreamAttributes>
 
 static char* opt_tag, *opt_tagnd, *created_by;
 
@@ -50,7 +51,7 @@ static route_head* rte;
 static Waypoint* wpt;
 
 static xg_callback	osm_node, osm_node_tag, osm_node_end;
-static xg_callback	osm_way, osm_way_nd, osm_way_tag, osm_way_end;
+static xg_callback	osm_way, osm_way_nd, osm_way_tag, osm_way_center, osm_way_end;
 
 static
 xg_tag_mapping osm_map[] = {
@@ -60,6 +61,7 @@ xg_tag_mapping osm_map[] = {
   { osm_way,	cb_start,	"/osm/way" },
   { osm_way_nd,	cb_start,	"/osm/way/nd" },
   { osm_way_tag,	cb_start,	"/osm/way/tag" },
+  { osm_way_center,	cb_start,	"/osm/way/center" },
   { osm_way_end,	cb_end,		"/osm/way" },
   { NULL,	(xg_cb_type)0,		NULL }
 };
@@ -427,9 +429,9 @@ osm_features_init(void)
 
 
 static char
-osm_feature_ikey(const char* key)
+osm_feature_ikey(const QString& key)
 {
-  return keys.value(QString::fromUtf8(key), -1);
+  return keys.value(key, -1);
 }
 
 
@@ -464,6 +466,15 @@ osm_strip_html(const char* str)
   return strip_html(&utf);	// util.cc
 }
 
+static QString
+osm_strip_html(const QString& str)
+{
+  char* r = osm_strip_html(CSTR(str));
+  QString rv(r);
+  xfree(r);
+  return rv;
+}
+
 
 static void
 osm_node_end(xg_string args, const QXmlStreamAttributes*)
@@ -486,10 +497,9 @@ osm_node(xg_string args, const QXmlStreamAttributes* attrv)
 
   if (attrv->hasAttribute("id")) {
     QString atstr = attrv->value("id").toString();
-
-    xasprintf(&wpt->description, "osm-id %s", CSTR(atstr));
+    wpt->description =  "osm-id " + atstr;
     if (waypoints.contains(atstr)) {
-      warning(MYNAME ": Duplicate osm-id %s!\n", CSTR(atstr));
+      warning(MYNAME ": Duplicate osm-id %s!\n", qPrintable(atstr));
     } else {
       waypoints.insert(atstr, wpt);
       wpt->wpt_flags.fmt_use = 1;
@@ -506,8 +516,8 @@ osm_node(xg_string args, const QXmlStreamAttributes* attrv)
   }
 
   if (attrv->hasAttribute("timestamp")) {
-    QByteArray tsutf8 = attrv->value("timestamp").toString().toUtf8();
-    wpt->creation_time = xml_parse_time(tsutf8.constData());
+    QString ts = attrv->value("timestamp").toString();
+    wpt->creation_time = xml_parse_time(ts);
   }
 }
 
@@ -515,60 +525,55 @@ osm_node(xg_string args, const QXmlStreamAttributes* attrv)
 static void
 osm_node_tag(xg_string args, const QXmlStreamAttributes* attrv)
 {
-  QByteArray qkey, qvalue;
-  const char* key = "", *value = "";
-  char* str;
+  QString key, value;
+  QString str;
   signed char ikey;
 
   if (attrv->hasAttribute("k")) {
-    qkey = attrv->value("k").toString().toUtf8();
-    key = qkey.constData();
+    key = attrv->value("k").toString();
   }
   if (attrv->hasAttribute("v")) {
-    qvalue = attrv->value("v").toString().toUtf8();
-    value = qvalue.constData();
+    value = attrv->value("v").toString();
   }
 
   str = osm_strip_html(value);
 
-  if (strcmp(key, "name") == 0) {
+  if (key == QLatin1String("name")) {
     if (wpt->shortname.isEmpty()) {
       wpt->shortname = str;
     }
-  } else if (strcmp(key, "name:en") == 0) {
+  } else if (key == QLatin1String("name:en")) {
     wpt->shortname = str;
   } else if ((ikey = osm_feature_ikey(key)) >= 0) {
-    wpt->icon_descr = osm_feature_symbol(ikey, value);
-  } else if (strcmp(key, "note") == 0) {
+    wpt->icon_descr = osm_feature_symbol(ikey, CSTR(value));
+  } else if (key == QLatin1String("note")) {
     if (wpt->notes.isEmpty()) {
       wpt->notes = str;
     } else {
       wpt->notes += "; ";
       wpt->notes += str;
     }
-  } else if (strcmp(key, "gps:hdop") == 0) {
-    wpt->hdop = atof(str);
-  } else if (strcmp(key, "gps:vdop") == 0) {
-    wpt->vdop = atof(str);
-  } else if (strcmp(key, "gps:pdop") == 0) {
-    wpt->pdop = atof(str);
-  } else if (strcmp(key, "gps:sat") == 0) {
-    wpt->sat = atoi(str);
-  } else if (strcmp(key, "gps:fix") == 0) {
-    if (strcmp(str, "2d") == 0) {
+  } else if (key == QLatin1String("gps:hdop")) {
+    wpt->hdop = str.toDouble();
+  } else if (key == QLatin1String("gps:vdop")) {
+    wpt->vdop = str.toDouble();
+  } else if (key == QLatin1String("gps:pdop")) {
+    wpt->pdop = str.toDouble();
+  } else if (key == QLatin1String("gps:sat")) {
+    wpt->sat = str.toDouble();
+  } else if (key == QLatin1String("gps:fix")) {
+    if (str == QLatin1String("2d")) {
       wpt->fix = fix_2d;
-    } else if (strcmp(str, "3d") == 0) {
+    } else if (str == QLatin1String("3d")) {
       wpt->fix = fix_3d;
-    } else if (strcmp(str, "dgps") == 0) {
+    } else if (str == QLatin1String("dgps")) {
       wpt->fix = fix_dgps;
-    } else if (strcmp(str, "pps") == 0) {
+    } else if (str == QLatin1String("pps")) {
       wpt->fix = fix_pps;
-    } else if (strcmp(str, "none") == 0) {
+    } else if (str == QLatin1String("none")) {
       wpt->fix = fix_none;
     }
   }
-
-  xfree(str);
 }
 
 
@@ -576,10 +581,10 @@ static void
 osm_way(xg_string args, const QXmlStreamAttributes* attrv)
 {
   rte = route_head_alloc();
-
+  // create a wpt to represent the route center if it has a center tag
+  wpt = new Waypoint;
   if (attrv->hasAttribute("id")) {
-    xasprintf(&rte->rte_desc, "osm-id %s",
-              attrv->value("id").toString().toUtf8().constData());
+    rte->rte_desc =  "osm-id " + attrv->value("id").toString();
   }
 }
 
@@ -596,7 +601,7 @@ osm_way_nd(xg_string args, const QXmlStreamAttributes* attrv)
       tmp = new Waypoint(*ctmp);
       route_add_wpt(rte, tmp);
     } else {
-      warning(MYNAME ": Way reference id \"%s\" wasn't listed under nodes!\n", CSTR(atstr));
+      warning(MYNAME ": Way reference id \"%s\" wasn't listed under nodes!\n", qPrintable(atstr));
     }
   }
 }
@@ -604,30 +609,52 @@ osm_way_nd(xg_string args, const QXmlStreamAttributes* attrv)
 static void
 osm_way_tag(xg_string args, const QXmlStreamAttributes* attrv)
 {
-  QByteArray qkey, qvalue;
-  const char* key = "", *value = "";
-  char* str;
+  QString key, value;
+  QString str;
+  signed char ikey;
 
   if (attrv->hasAttribute("k")) {
-    qkey = attrv->value("k").toString().toUtf8();
-    key = qkey.constData();
+    key = attrv->value("k").toString();
   }
   if (attrv->hasAttribute("v")) {
-    qvalue = attrv->value("v").toString().toUtf8();
-    value = qvalue.constData();
+    value = attrv->value("v").toString();
   }
 
   str = osm_strip_html(value);
 
-  if (strcmp(key, "name") == 0) {
+  if (key == QLatin1String("name")) {
     if (rte->rte_name.isEmpty()) {
       rte->rte_name = str;
+      wpt->shortname = str;
     }
-  } else if (strcmp(key, "name:en") == 0) {
+  } else if (key == QLatin1String("name:en")) {
     rte->rte_name = str;
-  }
 
-  xfree(str);
+    wpt->shortname = str;
+   // The remaining cases only apply to the center node
+  } else if ((ikey = osm_feature_ikey(key)) >= 0) {
+    wpt->icon_descr = osm_feature_symbol(ikey, CSTR(value));
+  } else if (key == "note") {
+    if (wpt->notes.isEmpty()) {
+      wpt->notes = str;
+    } else {
+      wpt->notes += "; ";
+      wpt->notes += str;
+    }
+  }
+}
+
+static void
+osm_way_center(xg_string args, const QXmlStreamAttributes* attrv)
+{
+  wpt->wpt_flags.fmt_use = 1;
+
+  if (attrv->hasAttribute("lat")) {
+    wpt->latitude = attrv->value("lat").toString().toDouble();
+  }
+  if (attrv->hasAttribute("lon")) {
+    wpt->longitude = attrv->value("lon").toString().toDouble();
+  }
 }
 
 static void
@@ -637,6 +664,15 @@ osm_way_end(xg_string args, const QXmlStreamAttributes*)
     route_add_head(rte);
     rte = NULL;
   }
+
+  if (wpt) {
+    if (wpt->wpt_flags.fmt_use) {
+      waypt_add(wpt);
+    } else {
+      delete(wpt);
+      wpt = NULL;
+    }
+  }
 }
 
 static void
@@ -904,7 +940,7 @@ static void
 osm_write(void)
 {
   gbfprintf(fout, "<?xml version='1.0' encoding='UTF-8'?>\n");
-  gbfprintf(fout, "<osm version='0.5' generator='GPSBabel");
+  gbfprintf(fout, "<osm version='0.6' generator='GPSBabel");
   if (gpsbabel_time != 0) {
     gbfprintf(fout, "-%s", gpsbabel_version);
   }
