@@ -23,11 +23,11 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA
  */
 
-#include <ctype.h>
-#include <math.h>
-
 #include "defs.h"
 #include "gbser.h"
+#include <math.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 #define MYNAME "skytraq"
 
