@@ -23,10 +23,12 @@
 
  */
 
-#include <ctype.h>
 #include "defs.h"
+#include "cet_util.h"
 #include "csv_util.h"
 #include "jeeps/gpsmath.h"
+#include <ctype.h>
+#include <stdlib.h>
 
 #if CSVFMTS_ENABLED
 #define MYNAME	"XCSV"
@@ -106,7 +108,6 @@ xcsv_destroy_style(void)
 {
   queue* elem, *tmp;
   field_map_t* fmp;
-  ogue_t* ogp;
   int internal = 0;
 
   /*
@@ -115,26 +116,10 @@ xcsv_destroy_style(void)
    */
 
   /* destroy the prologue */
-  QUEUE_FOR_EACH(&xcsv_file.prologue, elem, tmp) {
-    ogp = (ogue_t*)elem;
-    if (ogp->val) {
-      xfree(ogp->val);
-    }
-    if (elem) {
-      xfree(elem);
-    }
-  }
+  xcsv_file.epilogue.clear();
 
   /* destroy the epilogue */
-  QUEUE_FOR_EACH(&xcsv_file.epilogue, elem, tmp) {
-    ogp = (ogue_t*)elem;
-    if (ogp->val) {
-      xfree(ogp->val);
-    }
-    if (elem) {
-      xfree(elem);
-    }
-  }
+  xcsv_file.epilogue.clear();
 
   /* destroy the ifields */
   QUEUE_FOR_EACH(&xcsv_file.ifield, elem, tmp) {
@@ -177,21 +162,10 @@ xcsv_destroy_style(void)
   }
 
   /* other alloc'd glory */
-  if (xcsv_file.field_delimiter) {
-    xfree(xcsv_file.field_delimiter);
-  }
-
-  if (xcsv_file.field_encloser) {
-    xfree(xcsv_file.field_encloser);
-  }
-
-  if (xcsv_file.record_delimiter) {
-    xfree(xcsv_file.record_delimiter);
-  }
-
-  if (xcsv_file.badchars) {
-    xfree(xcsv_file.badchars);
-  }
+  xcsv_file.field_delimiter = QString();
+  xcsv_file.field_encloser = QString();
+  xcsv_file.record_delimiter = QString();
+  xcsv_file.badchars = QString();
 
   if (xcsv_file.description) {
     xfree(xcsv_file.description);
@@ -207,7 +181,6 @@ xcsv_destroy_style(void)
 
   /* return everything to zeros */
   internal = xcsv_file.is_internal;
-  memset(&xcsv_file, '\0', sizeof(xcsv_file));
   xcsv_file.is_internal = internal;
 }
 
@@ -253,25 +226,20 @@ xcsv_parse_style_line(char* sbuff)
       sp = csv_stringtrim(&sbuff[16], "\"", 1);
       cp = xcsv_get_char_from_constant_table(sp);
       if (cp) {
-        xcsv_file.field_delimiter = xstrdup(cp);
+        xcsv_file.field_delimiter = cp;
         xfree(sp);
       } else {
         xcsv_file.field_delimiter = sp;
       }
 
-      p = csv_stringtrim(xcsv_file.field_delimiter, " ", 0);
+      p = csv_stringtrim(CSTR(xcsv_file.field_delimiter), " ", 0);
 
       /* field delimiters are always bad characters */
       if (0 == strcmp(p, "\\w")) {
-        char* s = xstrappend(xcsv_file.badchars, " \n\r");
-        if (xcsv_file.badchars) {
-          xfree(xcsv_file.badchars);
-        }
-        xcsv_file.badchars = s;
+        xcsv_file.badchars = " \n\r";
       } else {
-        xcsv_file.badchars = xstrappend(xcsv_file.badchars, p);
+        xcsv_file.badchars += p;
       }
-
       xfree(p);
 
     } else
@@ -280,52 +248,30 @@ xcsv_parse_style_line(char* sbuff)
         sp = csv_stringtrim(&sbuff[15], "\"", 1);
         cp = xcsv_get_char_from_constant_table(sp);
         if (cp) {
-          xcsv_file.field_encloser = xstrdup(cp);
+          xcsv_file.field_encloser = cp;
           xfree(sp);
         } else {
           xcsv_file.field_encloser = sp;
         }
 
-        p = csv_stringtrim(xcsv_file.field_encloser, " ", 0);
-
-        /* field_enclosers are always bad characters */
-        if (xcsv_file.badchars) {
-          xcsv_file.badchars = (char*) xrealloc(xcsv_file.badchars,
-                                                strlen(xcsv_file.badchars) +
-                                                strlen(p) + 1);
-        } else {
-          xcsv_file.badchars = (char*) xcalloc(strlen(p) + 1, 1);
-        }
-
-        strcat(xcsv_file.badchars, p);
-
+        p = csv_stringtrim(CSTR(xcsv_file.field_encloser), " ", 0);
+        xcsv_file.badchars += p;
         xfree(p);
-
       } else
 
         if (ISSTOKEN(sbuff, "RECORD_DELIMITER")) {
           sp = csv_stringtrim(&sbuff[17], "\"", 1);
           cp = xcsv_get_char_from_constant_table(sp);
           if (cp) {
-            xcsv_file.record_delimiter = xstrdup(cp);
+            xcsv_file.record_delimiter = cp;
             xfree(sp);
           } else {
             xcsv_file.record_delimiter = sp;
           }
 
-          p = csv_stringtrim(xcsv_file.record_delimiter, " ", 0);
-
           /* record delimiters are always bad characters */
-          if (xcsv_file.badchars) {
-            xcsv_file.badchars = (char*) xrealloc(xcsv_file.badchars,
-                                                  strlen(xcsv_file.badchars) +
-                                                  strlen(p) + 1);
-          } else {
-            xcsv_file.badchars = (char*) xcalloc(strlen(p) + 1, 1);
-          }
-
-          strcat(xcsv_file.badchars, p);
-
+          p = csv_stringtrim(CSTR(xcsv_file.record_delimiter), " ", 0);
+          xcsv_file.badchars += p;
           xfree(p);
 
         } else
@@ -374,27 +320,17 @@ xcsv_parse_style_line(char* sbuff)
                       } else {
                         p = sp;
                       }
-
-                      if (xcsv_file.badchars) {
-                        xcsv_file.badchars = (char*) xrealloc(xcsv_file.badchars,
-                                                              strlen(xcsv_file.badchars) +
-                                                              strlen(p) + 1);
-                      } else {
-                        xcsv_file.badchars = (char*) xcalloc(strlen(p) + 1, 1);
-                      }
-
-                      strcat(xcsv_file.badchars, p);
-
+                      xcsv_file.badchars += p;
                       xfree(p);
 
                     } else
 
                       if (ISSTOKEN(sbuff, "PROLOGUE")) {
-                        xcsv_prologue_add(xstrdup(&sbuff[9]));
+                        xcsv_prologue_add(sbuff + 9);
                       } else
 
                         if (ISSTOKEN(sbuff, "EPILOGUE")) {
-                          xcsv_epilogue_add(xstrdup(&sbuff[9]));
+                          xcsv_epilogue_add(sbuff + 9);
                         } else
 
                           if (ISSTOKEN(sbuff, "ENCODING")) {
@@ -672,7 +608,7 @@ xcsv_wr_init(const char* fname)
       setshort_mustuniq(xcsv_file.mkshort_handle, atoi(snuniqueopt));
     }
 
-    setshort_badchars(xcsv_file.mkshort_handle, xcsv_file.badchars);
+    setshort_badchars(xcsv_file.mkshort_handle, CSTR(xcsv_file.badchars));
 
   }
   xcsv_file.gps_datum = GPS_Lookup_Datum_Index(opt_datum);
