@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: advdlg.h,v 1.2 2009/11/02 20:38:02 robertl Exp $
+// $Id: advdlg.h,v 1.2 2009-11-02 20:38:02 robertl Exp $
 //------------------------------------------------------------------------
 //
 //  Copyright (C) 2009  S. Khai Mong <khai@mangrai.com>.
@@ -29,18 +29,16 @@ class AdvDlg: public QDialog {
   
 public:
   AdvDlg(QWidget* parent, 
-	 bool &synthShortNames, 
-	 bool &enableCharSetXform,
-	 bool &previewGmap,
-	 int   &debugLevel);
-  QPushButton* formatButton() { return ui.formatButton; };
+   bool &synthShortNames_,
+   bool &previewGmap_,
+   int   &debugLevel_);
+  QPushButton* formatButton() { return ui_.formatButton; };
 
 private:
-  Ui_AdvUi ui;
-  bool &synthShortNames;
-  bool &enableCharSetXform;
-  bool &previewGmap;
-  int  &debugLevel;
+  Ui_AdvUi ui_;
+  bool &synthShortNames_;
+  bool &previewGmap_;
+  int  &debugLevel_;
 
  protected:
 
